@@ -33,9 +33,10 @@
 #  define LIBFACTER_DEPRECATED_NO_EXPORT LIBFACTER_NO_EXPORT LIBFACTER_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define LIBFACTER_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef LIBFACTER_NO_DEPRECATED
+#    define LIBFACTER_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
